@@ -2,8 +2,7 @@
 #
 # recfix.sh - System tests for recfix.
 #
-# Copyright (C) 2010, 2011, 2012, 2013, 2014, 2015, 2020 Jose E.
-# Marchesi.
+# Copyright (C) 2010-2022 Jose E. Marchesi.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1379,6 +1378,52 @@ xxx: 20
 zzz: 40
 yyy: 30
 '
+
+test_declare_input_file multiple-singulars \
+'%rec: Foo
+%singular: Id
+%unique: Id
+
+Id: 0
+Name: Name1
+
+Id: 2
+Name: Name2
+
+Id: 2
+Name: Name3
+'
+
+test_declare_input_file blanks-before-fex-in-type \
+'%rec: Bug
+%mandatory: Id Title Desc Status Reporter Time
+%typedef: Id_t  int
+%type:  Id   Id_t
+%typedef: Status_t enum TODO ACTIVE DOING DONE
+%type: Status Status_t
+
+Id: 1
+Title: first bug
+Desc:  test recfiles
+Status: DONE
+Reporter: Hao Wu
+Time:  Thu Jan 30 14:11:05 CST 2020
+
+Id: 2
+Title: first bug
+Title: first bug
+Desc:  test recfiles
+Status: DONE
+Reporter: Hao Wu
+Time: : Thu Jan 30 14:10:56 CST 2020
+
+Id: 3
+Title: learn recfiles
+Desc: learn recfiles
+Status: DOING
+Reporter: Hao Wu
+Time: Mon Feb  3 14:35:03 CST 2020
+'                        
                         
 #
 # Declare tests.
@@ -2409,7 +2454,18 @@ test_tool recfix-allowed-xfail-3 xfail \
           recfix \
           '--check' \
           allowed-xfail-3
-        
+
+test_tool recfix-blanks-before-fex-in-type ok \
+          recfix \
+          '--check' \
+          blanks-before-fex-in-type \
+          ''
+
+test_tool recfix-multiple-singulars xfail \
+          recfix \
+          '--check' \
+          multiple-singulars
+
 #
 # Cleanup.
 #
