@@ -2,8 +2,7 @@
 #
 # recfmt.sh - System tests for recfmt.
 #
-# Copyright (C) 2010, 2011, 2012, 2013, 2014, 2015, 2020 Jose E.
-# Marchesi.
+# Copyright (C) 2010-2022 Jose E. Marchesi.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -127,6 +126,17 @@ value21 value22value23
 value31 value32value33
 '
 
+# Apply a template containing curly-brace markup.
+test_tool recfmt-curly ok \
+          recfmt \
+          '"\def\field1{{{field1}}}
+"' \
+          multiple-records \
+'\def\field1{value11}
+\def\field1{value21}
+\def\field1{value31}
+'
+
 # Try to apply an empty slot.
 test_tool recfmt-empty-slot xfail \
           recfmt \
